@@ -37,23 +37,3 @@ def visit_dir(path):
     os.chdir(path)
     yield
     os.chdir(current_dir)
-
-
-class AttrDict(dict):
-    """
-    Dictionary with attribute access to keys.
-    """
-
-    def __getattr__(self, attr):
-        try:
-            return self[attr]
-        except KeyError:
-            raise AttributeError
-
-    def __setattr__(self, attr, value):
-        self[attr] = value
-
-    def sub(self, keys):
-        if isinstance(keys, str):
-            keys = keys.split()
-        return AttrDict({k: self[k] for k in keys})
\ No newline at end of file
